package com.gree.mall.manager.logic.apply;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gree.mall.manager.bean.activity.PromotionActivityBatchBean;
import com.gree.mall.manager.bean.admin.AdminUserCom;
import com.gree.mall.manager.bean.apply.WorkerInvolvePrincipalDetail;
import com.gree.mall.manager.bean.apply.WorkerInvolvePrincipalVO;
import com.gree.mall.manager.bean.es.ESGoodsVO;
import com.gree.mall.manager.commonmapper.CommonMapper;
import com.gree.mall.manager.exception.RemoteServiceException;
import com.gree.mall.manager.logic.common.CommonLogic;
import com.gree.mall.manager.plus.entity.WorkerInvolvePrincipal;
import com.gree.mall.manager.plus.entity.WorkerInvolvePrincipalItem;
import com.gree.mall.manager.plus.service.WorkerInvolvePrincipalItemService;
import com.gree.mall.manager.plus.service.WorkerInvolvePrincipalService;
import com.gree.mall.manager.zfire.bean.ZfireParamBean;
import com.gree.mall.manager.zfire.util.FieldUtils;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;

@Slf4j
@Service
@RequiredArgsConstructor
public class WorkerInvolveLogic {

    private final CommonLogic commonLogic;
    private final CommonMapper commonMapper;
    private final WorkerInvolvePrincipalService workerInvolvePrincipalService;
    private final WorkerInvolvePrincipalItemService workerInvolvePrincipalItemService;

    public IPage<WorkerInvolvePrincipalVO> list(ZfireParamBean zfireParamBean) {

        AdminUserCom adminUser = commonLogic.getAdminUser();
        FieldUtils.supplyParam(zfireParamBean, WorkerInvolvePrincipalVO.class, adminUser);
        IPage<WorkerInvolvePrincipalVO> page = commonMapper.principalPage(new Page(zfireParamBean.getPageNum(), zfireParamBean.getPageSize()), zfireParamBean);

        return page;
    }

    public WorkerInvolvePrincipalDetail detail(String id) {
        WorkerInvolvePrincipal workerInvolvePrincipal = workerInvolvePrincipalService.getById(id);

        WorkerInvolvePrincipalDetail workerInvolvePrincipalDetail = BeanUtil.toBean(workerInvolvePrincipal, WorkerInvolvePrincipalDetail.class);

        List<WorkerInvolvePrincipalItem> workerInvolve = workerInvolvePrincipalItemService.lambdaQuery().eq(WorkerInvolvePrincipalItem::getPrincipalId, id).list();

        workerInvolvePrincipalDetail.setWorkerInvolvePrincipalItems(workerInvolve);

        return workerInvolvePrincipalDetail;
    }

    public void add(WorkerInvolvePrincipalDetail bean) {

        if (workerInvolvePrincipalService.lambdaQuery().eq(WorkerInvolvePrincipal::getPrincipal,bean.getId())
        .count() > 0)
            throw new RemoteServiceException("存在相同审批人名称");

        bean.insert();

        for (WorkerInvolvePrincipalItem workerInvolvePrincipalItem : bean.getWorkerInvolvePrincipalItems()) {
            workerInvolvePrincipalItem.setPrincipalId(bean.getId());
        }

        workerInvolvePrincipalItemService.saveBatch(bean.getWorkerInvolvePrincipalItems());
    }

    public void update(WorkerInvolvePrincipalDetail bean) {


        if (workerInvolvePrincipalService.lambdaQuery().eq(WorkerInvolvePrincipal::getPrincipal,bean.getId())
                .ne(WorkerInvolvePrincipal::getId,bean.getId())
                .count() > 0)
            throw new RemoteServiceException("存在相同审批人名称");

        bean.updateById();

        workerInvolvePrincipalItemService.lambdaUpdate()
                .eq(WorkerInvolvePrincipalItem::getPrincipalId,bean.getId())
                .remove();

        for (WorkerInvolvePrincipalItem workerInvolvePrincipalItem : bean.getWorkerInvolvePrincipalItems()) {
            workerInvolvePrincipalItem.setPrincipalId(bean.getId());
        }

        workerInvolvePrincipalItemService.saveBatch(bean.getWorkerInvolvePrincipalItems());
    }
}
